==> driza-unix-0.2.tar.gz: driza-unix-0.2/src/variables.py <==
#####
# Fichero de variables
# Guarda todos los Variables relacionados con los Variables que maneja el programa
####

#Copyright (C) 2006  Inmaculada Luengo Merino, Nstor Arocha Rodrguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


class Variable:
	"""Variable generico. De esta clase heredan los Variables usados en el programa """
	def __init__(self,nombre=None,titulo=None,valores=None,ancho=None,decimales=None,valorpordefecto=None,descripcion=None):
		self.nombre=nombre
	#	if self.comprobar(valorpordefecto):
		self.valorpordefecto=valorpordefecto
		self.titulo=titulo
		self.ancho=ancho
		self.decimales=decimales
		self.descripcion=descripcion
		if valores == None: self.valores={}
		else: self.valores=dict()

	def update(self,objeto):
		"""Funcin de copia de los atributos para cualquier variable"""
		self.nombre=objeto.nombre
		self.valorpordefecto=objeto.valorpordefecto
		self.titulo=objeto.titulo
		self.ancho=objeto.ancho
		self.decimales=objeto.decimales
		self.descripcion=objeto.descripcion
		if objeto.valores:
			self.valores=objeto.valores.copy()
	def set_val(self,array):
		"""Coge todos los valores que caracterizan a la variable de un array"""
		(self.nombre,self.titulo,self.ancho,self.decimales,self.valores)=array

	def get_val(self):
		"""Devuelve todos los valores que caracteriza a una variable"""
		return [self.nombre,self.titulo,self.ancho,self.decimales,self.valores]

	def __setitem__(self,indice,valor):
		if indice==0:
			self.nombre=valor
			print valor
		elif indice==2:
			self.titulo=valor
		else:
			print "no implementdo"
	def comprobar(self,valor):
		"""Funcin de comprobacin de la correctitud de un valor"""
		return True

class Entero(Variable):
	"""La clase entero. El formato interno ser "int" """
	def __init__(self,nombre=None,titulo=None,valores=None,ancho=None,decimales=None,valorpordefecto=None):
		Variable.__init__(self,nombre,titulo,valores,ancho,decimales,valorpordefecto)
		self.tipo="Entero"
	def interno(self,valor):
		"""transforma el valor al formato en el que se desea guardar, 
		comparando si un valor dado se ajusta al tipo de variable
		Genera una excepcin en caso de que la conversin no funcione
		"""
		#http://honors.montana.edu/~jjc/easytut/easytut/node16.html
		#Aprovecha la funcion eval de python
		#import types
		#if type(int(valor))==types.IntType: return True
		#Mejor capturar la excepcion al hacer la funcion int
		return int(valor)
	def ristra(self,valor):
		"""Esta funcin transforma un valor en formato interno al formato de representacin (Cadena)"""
		return repr(valor)

class Real(Variable):
	def __init__(self,nombre=None,titulo=None,valores=None,ancho=None,decimales=None,valorpordefecto=None):
		Variable.__init__(self,nombre,titulo,valores,ancho,decimales,valorpordefecto)
		self.tipo="Real"
	def comprobar(self,valor):
		"""Compara con una expresin regular"""
		pass 

class Booleano(Variable):
	def __init__(self,nombre=None,titulo=None,valores=None,ancho=None,decimales=None,valorpordefecto=None):
		Variable.__init__(self,nombre,titulo,valores,ancho,decimales,valorpordefecto)
		self.tipo="Booleano"
	def comprobar(self,valor):
		"""Compara con una expresin regular"""
		pass 

class Fecha(Variable):
	def __init__(self,nombre,titulo,valores,ancho,decimales,valorpordefecto):
		Variable.__init__(self,nombre,titulo,valores,ancho,decimales,valorpordefecto)
	def comprobar(self,valor):
		"""Compara con una expresin regular"""
		pass 

class Dinero(Variable):
	def __init__(self=None,nombre=None,titulo=None,valores=None,ancho=None,decimales=None,valorpordefecto=None):
		Variable.__init__(self,nombre,titulo,valores,ancho,decimales,valorpordefecto)
		self.tipo="Dinero"
	def comprobar(self,valor):
		"""Compara con una expresin regular"""
		return True

==> driza-unix-0.3.tar.gz: driza-unix-0.3/src/variables.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#####
# Fichero de variables
# Guarda todos los Variables relacionados con los Variables que maneja el programa
####

#Copyright (C) 2006  Inmaculada Luengo Merino, Nstor Arocha Rodrguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


class Variable:
	"""Variable generico. De esta clase heredan los Variables usados en el programa """
	def __init__(self,nombre,valores,valorpordefecto,descripcion):
		self.nombre=nombre
		self.valorpordefecto=valorpordefecto
		self.descripcion=descripcion
		if valores == None: self.valores={}
		else: self.valores=valores

	def update(self,objeto):
		"""Funcin de copia de los atributos para cualquier variable"""
		self.nombre=objeto.nombre
		self.valorpordefecto=objeto.valorpordefecto
		self.descripcion=objeto.descripcion
		if objeto.valores:
			self.valores=objeto.valores.copy()
	def set_val(self,array):
		"""Coge todos los valores que caracterizan a la variable de un array"""
		(self.nombre,self.valores)=array

	def get_val(self):
		"""Devuelve todos los valores que caracteriza a una variable"""
		return [self.nombre,self.valores]

	def __setitem__(self,indice,valor):
		if indice==0:
			self.nombre=valor
		elif indice==3:
			self.valorpordefecto=valor
		elif indice==4:
			self.descripcion=valor

	def __getitem__(self,indice):
		if indice==0:
			return self.nombre
		elif indice==3:
			return self.valorpordefecto
		elif indice==4:
			return self.descripcion
	def comprobar(self,valor):
		"""Funcin de comprobacin de la correctitud de un valor"""
		return True

class Entero(Variable):
	"""La clase entero. El formato interno ser "int" """
	def __init__(self,nombre=None,valores=None,valorpordefecto=0,descripcion=None):
		Variable.__init__(self,nombre,valores,valorpordefecto,descripcion)
		self.tipo="Entero"
	def interno(self,valor):
		"""transforma el valor al formato en el que se desea guardar, 
		comparando si un valor dado se ajusta al tipo de variable
		Genera una excepcin en caso de que la conversin no funcione
		"""
		#http://honors.montana.edu/~jjc/easytut/easytut/node16.html
		#Aprovecha la funcion eval de python
		#import types
		#if type(int(valor))==types.IntType: return True
		#Mejor capturar la excepcion al hacer la funcion int
		return int(valor)
	def ristra(self,valor):
		"""Esta funcin transforma un valor en formato interno al formato de representacin (Cadena)"""
		return repr(valor)

class Real(Variable):
	def __init__(self,nombre=None,valores=None,valorpordefecto=None):
		Variable.__init__(self,nombre,valores,valorpordefecto)
		self.tipo="Real"
	def comprobar(self,valor): #DEPRECATED
		"""Compara con una expresin regular""" 
		pass 

class Booleano(Variable):
	def __init__(self,nombre=None,valores=None,valorpordefecto=None,descripcion=None):
		Variable.__init__(self,nombre,valores,valorpordefecto,descripcion)
		self.tipo="Booleano"
	def interno(self,valor):
		"""Paso al formato interno, si el dato no es vlido generar una excepcin"""
		if valor:
			return True
		else:
			return False
	def ristra(self,valor):
		if valor:
			return "1"
		else:
			return "0"
	def comprobar(self,valor):
		"""Compara con una expresin regular"""
		pass 

class Fecha(Variable):
	def __init__(self,nombre,valores,valorpordefecto):
		Variable.__init__(self,nombre,valores,valorpordefecto)
	def comprobar(self,valor):
		"""Compara con una expresin regular"""
		pass
